@@ -2,15 +2,18 @@
 
 package Test::Regexp::Pattern;
 
-our $DATE = '2018-09-12'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-13'; # DATE
+our $DIST = 'Test-Regexp-Pattern'; # DIST
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
 
-use Regexp::Pattern qw(re);
 use File::Spec;
+use Hash::DefHash; # exports defhash()
+use Regexp::Pattern qw(re);
 use Test::Builder;
 use Test::More ();
 
@@ -28,10 +31,17 @@ sub import {
 }
 
 sub _test_regexp_pattern {
-    my ($re, $fqname, $opts) = @_;
+    my ($re, $parent, $fqname, $opts) = @_;
     my $ok = 1;
 
   GENERAL: {
+        my $dh;
+        eval { $dh = Hash::DefHash->new($re, parent=>$parent); 1 };
+        my $eval_err = $@;
+        $Test->ok(!$eval_err, "Must be a valid defhash") or do {
+            $Test->diag("error in defhash check: $eval_err");
+            $ok = 0;
+        };
         $Test->ok(($re->{pat} xor $re->{gen}), "Must declare pat OR gen but not both") or $ok = 0;
     }
 
@@ -50,12 +60,16 @@ sub _test_regexp_pattern {
                         $ok = 0;
                         return;
                     };
+
                     my %args;
                     if ($eg->{gen_args}) {
                         $args{$_} = $eg->{gen_args}{$_} for keys %{$eg->{gen_args}};
                     }
-
+                    if (defined $eg->{anchor}) {
+                        $args{-anchor} = $eg->{anchor};
+                    }
                     my $pat = re($fqname, %args);
+
                     my $actual_match = $eg->{str} =~ $pat ? 1:0;
                     if (ref $eg->{matches} eq 'ARRAY') {
                         my $len = @{ $eg->{matches} };
@@ -140,13 +154,15 @@ sub regexp_patterns_in_module_ok {
                 goto L1;
             }
 
-            for my $name (sort keys %{ "$module\::RE" }) {
-                my $re = ${"$module\::RE"}{$name};
+            my $RE = \%{ "$module\::RE" };
+            my $dh = defhash($RE);
+            for my $name ($dh->props) {
+                my $re = $RE->{$name};
                 $has_tests++;
                 $Test->subtest(
                     "pattern $prefix$name",
                     sub {
-                        _test_regexp_pattern($re, "$prefix$name", \%opts) or $ok = 0;
+                        _test_regexp_pattern($re, $RE, "$prefix$name", \%opts) or $ok = 0;
                     },
                 ) or $ok = 0;
             }
@@ -261,13 +277,13 @@ Test::Regexp::Pattern - Test Regexp::Pattern patterns
 
 =head1 VERSION
 
-This document describes version 0.004 of Test::Regexp::Pattern (from Perl distribution Test-Regexp-Pattern), released on 2018-09-12.
+This document describes version 0.007 of Test::Regexp::Pattern (from Perl distribution Test-Regexp-Pattern), released on 2021-07-13.
 
 =head1 SYNOPSIS
 
 To check all regexp patterns in a module:
 
- use Test::Regexp::Patterns tests=>1;
+ use Test::Regexp::Pattern;
  regexp_patterns_in_module_ok("Foo::Bar", {opt => ...}, $msg);
 
 Alternatively, you can check all regexp patterns in all modules in a distro:
@@ -285,8 +301,8 @@ This module performs various checks on a module's L<Regexp::Pattern> patterns.
 It is recommended that you include something like C<release-regexp-pattern.t> in
 your distribution if you add regexp patterns to your code. If you use
 L<Dist::Zilla> to build your distribution, there is
-L<[Test::Regexp::Pattern]|Dist::Zilla::Plugin::Test::Regexp::Pattern> to make it
-easy to do so.
+L<[Regexp::Pattern]|Dist::Zilla::Plugin::Regexp::Pattern> which automatically
+adds a release test file for this during build.
 
 =for Pod::Coverage ^(all_modules)$
 
@@ -340,7 +356,7 @@ C<regexp_patterns_in_all_modules_ok()>.
 
 L<Regexp::Pattern>
 
-L<Dist::Zilla::Plugin::Test::Regexp::Pattern>
+L<Dist::Zilla::Plugin::Regexp::Pattern>
 
 =head1 AUTHOR
 
@@ -348,7 +364,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
